# oikos
Oikos is a Python library focused on economic analysis and basic economic theory models.

## Installation
```bash
pip install oikos
```

## License
The software is licensed under the MIT license, with copyright by Marcos Jr.